#grid cluster


# make att cluster function
att_clust <- function (obj, formula, data, model = "linear", extrapolate = FALSE, 

    ntree = 2000, clustVar = NULL) 

{

    mod.type <- NULL

    mod <- NULL

    if ((class(obj)[1] != "cem.match") && (class(obj)[1] != "cem.match.list")) 

        stop("Argument `obj' must be a `cem.match' or `cem.match.list' object")

    mods <- c("linear", "lm", "lme", "linear-RE", "logit", "logistic", 

        "rf", "forest")

    if (!(model %in% mods)) 

        stop(sprintf("model `%s' not yet implemented", model))

    if (model %in% c("lm", "linear")) {

        mod <- "lm"

        mod.type <- "Linear regression model"

    }

    if (model %in% c("lme", "linear-RE")) {

        mod <- "lme"

        mod.type <- "Linear random effect model"

    }

    if (model %in% c("forest", "rf")) {

        mod <- "randomForest"

        mod.type <- "Random forest model"

    }

    if (model %in% c("logit", "logistic")) {

        mod <- "glm"

        mod.type <- "Logistic model"

    }

    random.cem <- NULL

    random.all <- NULL

    ranef.cem <- NULL

    ranef.all <- NULL

    reg.cem <- NULL

    reg.all <- NULL

    rf.cem <- NULL

    TE <- NULL

    control = lmeControl(maxIter = 1000, opt = "optim")

    if (class(obj)[1] == "cem.match") {

        if (mod == "randomForest") {

            require(randomForest, quietly = TRUE)

            out <- do.call(mod, list(formula = formula, data = data, 

                subset = obj$matched == TRUE & obj$groups == 

                  obj$g.names[1], ntree = ntree))

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data)

            TEi <- data[, response] - prd

            if (extrapolate) {

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  mean(TEi[idt])

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                ww <- table(obj$strata, obj$groups)[, 2]

                w.coef <- weighted.mean(TE, ww, na.rm = TRUE)

                idx <- which(is.na(TE))

                if (length(idx) > 0) 

                  TE <- TE[-idx]

                rf.cem <- matrix(NA, 4, 1)

                v0 <- var(data[obj$groups == obj$g.names[2], 

                  response])

                v1 <- var(prd[obj$groups == obj$g.names[2]])

            }

            else {

                g <- function(i) {

                  idt <- which(obj$mstrata == i & obj$groups == 

                    obj$g.names[2])

                  mean(TEi[idt])

                }

                mstrata <- na.omit(unique(obj$mstrata))

                TE <- sapply(mstrata, g)

                names(TE) <- mstrata

                ww <- table(obj$mstrata, obj$groups)[, 2]

                w.coef <- weighted.mean(TE, ww, na.rm = TRUE)

                idx <- which(is.na(TE))

                if (length(idx) > 0) 

                  TE <- TE[-idx]

                rf.cem <- matrix(NA, 4, 1)

                v0 <- var(data[obj$matched == TRUE & obj$groups == 

                  obj$g.names[2], response])

                v1 <- var(prd[obj$matched == TRUE & obj$groups == 

                  obj$g.names[2]])

            }

            dimnames(rf.cem) <- list(c("Estimate", "Std. Error", 

                "t value", "p-value"), obj$treatment)

            rf.cem["Estimate", ] <- w.coef

            rf.cem["Std. Error", ] <- sqrt((v1 + v0) * sum(ww^2)/sum(ww)^2)

            rf.cem["t value", ] <- rf.cem["Estimate", ]/rf.cem["Std. Error", 

                ]

            rf.cem["p-value", ] <- 2 * (1 - pnorm(rf.cem["t value", 

                ]))

            att.model <- rf.cem

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "lme") {

            require(nlme, quietly = TRUE)

            data1 <- data

            data1$allID <- factor(obj$strata)

            data1$cemID <- factor(obj$mstrata)

            data1$matched <- obj$matched

            matched <- obj$matched

            f1 <- formula(sprintf(" ~ %s | allID", obj$treatment))

            f2 <- formula(sprintf(" ~ %s | cemID", obj$treatment))

            if (extrapolate) {

                rand.try <- try(lme(update(formula, ~. - cemID - 

                  allID - matched), data = data1, random = f1, 

                  keep.data = FALSE, control = control), silent = TRUE)

                if (class(rand.try) == "try-error") {

                  cat("\nCannot estimate the random effects model for the complete data set\n")

                }

                else {

                  rand.all <- rand.try

                  random.all <- t(summary(rand.all)$tTable)

                  rand.cf <- coef(rand.all)

                  ww <- table(obj$strata, obj$groups)[, 2]

                  cf.idx <- match(rownames(rand.cf), names(ww))

                  rownames(random.all) <- c("Estimate", "Std. Error", 

                    "DF", "t value", "p-value")

                  w.coef <- apply(rand.cf, 2, function(x) weighted.mean(x, 

                    w = ww[cf.idx]))

                  random.all["Estimate", ] <- w.coef

                  random.all["Std. Error", ] <- random.all["Std. Error", 

                    ] * sqrt(sum(ww^2)/sum(ww)^2)

                  random.all["t value", ] <- random.all["Estimate", 

                    ]/random.all["Std. Error", ]

                  random.all["p-value", ] <- 2 * (1 - pnorm(random.all["t value", 

                    ]))

                  att.model <- random.all

                  TE <- rand.cf[, obj$treatment]

                  names(TE) <- rownames(rand.cf)

                }

            }

            else {

                rand.try <- try(lme(update(formula, ~. - cemID - 

                  allID - matched), data = data1, random = f2, 

                  subset = matched == TRUE, keep.data = FALSE, 

                  control = control), silent = TRUE)

                if (class(rand.try) == "try-error") {

                  cat("\nCannot estimate the random effects model for the CEM matched subsample\n")

                }

                else {

                  rand.cem <- rand.try

                  random.cem <- t(summary(rand.cem)$tTable)

                  rand.cf <- coef(rand.cem)

                  ww <- table(obj$mstrata, obj$groups)[, 2]

                  cf.idx <- match(rownames(rand.cf), names(ww))

                  rownames(random.cem) <- c("Estimate", "Std. Error", 

                    "DF", "t value", "p-value")

                  w.coef <- apply(rand.cf, 2, function(x) weighted.mean(x, 

                    w = ww[cf.idx]))

                  random.cem["Estimate", ] <- w.coef

                  random.cem["Std. Error", ] <- random.cem["Std. Error", 

                    ] * sqrt(sum(ww^2)/sum(ww)^2)

                  random.cem["t value", ] <- random.cem["Estimate", 

                    ]/random.cem["Std. Error", ]

                  random.cem["p-value", ] <- 2 * (1 - pnorm(random.cem["t value", 

                    ]))

                  ranef.cem <- random.effects(rand.cem)

                  att.model <- random.cem

                  TE <- rand.cf[, obj$treatment]

                  names(TE) <- rownames(rand.cf)

                }

            }

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "lm") {

            out <- do.call(mod, list(formula = formula, data = data, 

                weights = obj$w))

            fit <- fitted(out)

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data)

            TEi <- data[, response] - prd

            g <- function(i) {

                idt <- which(obj$mstrata == i & obj$groups == 

                  obj$g.names[2])

                mean(TEi[idt])

            }

            mstrata <- na.omit(unique(obj$mstrata))

            TE <- sapply(mstrata, g)

            names(TE) <- mstrata

            idx <- which(is.na(TE))

            if (length(idx) > 0) 

                TE <- TE[-idx]

			#browser()

			# FDWW: calculate grid-clustered errors here instead

			if (length(clustVar) > 0) { print("clustered std errs being calculated for lm model")

				reg.cem <- t(clustErrs(out, clustVar))

				#rownames(reg.cem) <- c("Estimate", "Clust. Std. Err.", "Clust. z value", "Clust. Pr(>|z|)")	# don't change these names -- it interferes with summary/print functions

			} else {

				reg.cem <- t(summary(out)$coefficients)

			}

			rownames(reg.cem) <- c("Estimate", "Std. Error", 

                "t value", "p-value")

            att.model <- reg.cem

            if (extrapolate) {

                idx2 <- which(!obj$matched & obj$groups == obj$g.names[2])

                f3 <- formula(sprintf(" ~  . -%s ", obj$treatment))

                f4 <- update(formula, f3)

                tmp.data <- data[idx2, ]

                tmp.data[obj$treatment] <- 0

                y1 <- predict(out, newdata = tmp.data)

                response <- all.vars(f4)[attr(terms(formula), 

                  "response")]

                tmp <- t.test(y1, data[idx2, response])

                att4 <- diff(tmp$estimate)

                att4.serr <- abs(diff(tmp$estimate)/tmp$statistic)

                p <- obj$tab[2, 2]/obj$tab[1, 2]

                att4 <- (1 - p) * att4 + p * reg.cem["Estimate", 

                  obj$treatment]

                reg.all <- matrix(NA, 4, 1)

                rownames(reg.all) <- rownames(reg.cem)

                colnames(reg.all) <- obj$treatment

                reg.all["Estimate", 1] <- att4

                reg.all["Std. Error", 1] <- sqrt(p^2 * reg.cem["Std. Error", 

                  obj$treatment]^2 + (1 - p)^2 * att4.serr^2)

                reg.all["t value", 1] <- att4/att4.serr

                reg.all["p-value", 1] <- 2 * (1 - pnorm(att4/att4.serr))

                reg.cem <- NULL

                att.model <- reg.all

                TE <- NULL

                fit <- fitted(out)

                tmp.data <- data

                tmp.data[obj$treatment] <- 0

                prd <- predict(out, tmp.data)

                TEi <- data[, response] - prd

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  if (length(idt) > 0) 

                    return(mean(TEi[idt]))

                  return(NA)

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                idx <- which(is.na(TE))

                TE <- TE[-idx]

            }

			# add lm regression object to returned list (lmObj = out)

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE, lmObj = out)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "glm") {

            out <- do.call(mod, list(formula = formula, data = data, 

                weights = obj$w, family = "binomial"))

            fit <- fitted(out)

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data, type = "response")

            TEi <- data[, response] - prd

            g <- function(i) {

                idt <- which(obj$mstrata == i & obj$groups == 

                  obj$g.names[2])

                mean(TEi[idt])

            }

            mstrata <- na.omit(unique(obj$mstrata))

            TE <- sapply(mstrata, g)

            names(TE) <- mstrata

            idx <- which(is.na(TE))

            if (length(idx) > 0) 

                TE <- TE[-idx]

            reg.cem <- t(summary(out)$coefficients)

			# TODO: calculate grid clustered std errors for logit models?

            rownames(reg.cem) <- c("Estimate", "Std. Error", 

                "t value", "p-value")

            att.model <- reg.cem

            if (extrapolate) {

                idx2 <- which(!obj$matched & obj$groups == obj$g.names[2])

                f3 <- formula(sprintf(" ~  . -%s ", obj$treatment))

                f4 <- update(formula, f3)

                tmp.data <- data[idx2, ]

                tmp.data[obj$treatment] <- 0

                y1 <- predict(out, newdata = tmp.data, type = "response")

                response <- all.vars(f4)[attr(terms(formula), 

                  "response")]

                tmp <- t.test(y1, data[idx2, response])

                att4 <- diff(tmp$estimate)

                att4.serr <- abs(diff(tmp$estimate)/tmp$statistic)

                p <- obj$tab[2, 2]/obj$tab[1, 2]

                att4 <- (1 - p) * att4 + p * reg.cem["Estimate", 

                  obj$treatment]

                reg.all <- matrix(NA, 4, 1)

                rownames(reg.all) <- rownames(reg.cem)

                colnames(reg.all) <- obj$treatment

                reg.all["Estimate", 1] <- att4

                reg.all["Std. Error", 1] <- sqrt(p^2 * reg.cem["Std. Error", 

                  obj$treatment]^2 + (1 - p)^2 * att4.serr^2)

                reg.all["t value", 1] <- att4/att4.serr

                reg.all["p-value", 1] <- 2 * (1 - pnorm(att4/att4.serr))

                reg.cem <- NULL

                att.model <- reg.all

                TE <- NULL

                tmp.data <- data

                tmp.data[obj$treatment] <- 0

                prd <- predict(out, tmp.data, type = "response")

                TEi <- data[, response] - prd

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  if (length(idt) > 0) 

                    return(mean(TEi[idt]))

                  return(NA)

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                idx <- which(is.na(TE))

                TE <- TE[-idx]

            }

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

    }

    if (class(data) != "list") 

        stop("Argument `data' must be a list of `data.frame's")

    n.cems <- length(obj) - 1

    if (length(data) != n.cems) 

        stop("lengths of `cem.match.list' object and `data' do not match")

    est <- vector(n.cems, mode = "list")

    for (i in 1:n.cems) {

        out <- att(obj[[i]], formula = formula, data = data[[i]], 

            model = model, extrapolate = extrapolate)

        est[[i]] <- out

    }

    ncoef <- NCOL(est[[1]])

    qoi <- numeric(ncoef)

    seq <- numeric(ncoef)

    for (i in 1:n.cems) {

        att.m <- est[[i]]$att.model

        qoi <- qoi + att.m["Estimate", ]

        seq <- seq + att.m["Std. Error", ]^2

    }

    qoi <- qoi/n.cems

    seq <- seq/n.cems

    s2 <- numeric(ncoef)

    for (i in 1:n.cems) {

        att.m <- est[[i]]$att.model

        s2 <- s2 + (att.m["Estimate", ] - qoi)^2

    }

    s2 <- s2/(n.cems - 1)

    S <- sqrt(seq + s2 * (1 + 1/n.cems))

    TE <- vector(n.cems, mode = "list")

    for (i in 1:n.cems) TE[[i]] <- est[[i]]$TE

    att.model <- rbind(qoi, S)

    att.model <- rbind(att.model, att.model[1, ]/att.model[2, 

        ])

    att.model <- rbind(att.model, 2 * (1 - pnorm(att.model[3, 

        ])))

    if (colnames(att.model)[1] == "qoi") 

        colnames(att.model)[1] <- obj[[1]]$treatment

    rownames(att.model) <- c("Estimate", "Std. Error", "t value", 

        "p-value")

    out <- list(mult = est, att.model = att.model, treatment = obj[[1]]$treatment, 

        extrapolate = extrapolate, mod.type = mod.type, TE = TE)

    class(out) <- "cem.att"

    out

}

baseDir<-"... PUT IN YOUR DIRECTORY "

library (cem)

setwd(baseDir)

#these lines load scripts to set up the data cleanly and for common functions (really, the att_clust modification could be there)
source(paste(baseDir, "SharedClimateModelFunctions.R", sep=""))

load(file=paste(baseDir, "pastLongDataB_W.Rdata", sep=""))

names(pastLongData)
dim(pastLongData)




#vars we want (for binary operations):
pastLongData$TI6_veryHot <- ifelse (pastLongData$TI6_CRU >= 2, c(1), c(0))
pastLongData$TI6_Hot<- ifelse (pastLongData$TI6_CRU >= 1, c(1), c(0))
pastLongData$TI6_veryCold <- ifelse (pastLongData$TI6_CRU <= -2, c(1), c(0))
pastLongData$TI6_Cold<- ifelse (pastLongData$TI6_CRU <= -1, c(1), c(0))

pastLongData$SPI6_veryWet <- ifelse (pastLongData$SPI6_CRU >= 2, c(1), c(0))
pastLongData$SPI6_Wet<- ifelse (pastLongData$SPI6_CRU >= 1, c(1), c(0))
pastLongData$SPI6_veryDry <- ifelse (pastLongData$SPI6_CRU <= -2, c(1), c(0))
pastLongData$SPI6_Dry<- ifelse (pastLongData$SPI6_CRU <= -1, c(1), c(0))

#these are interactions for hot/dry, etc. combined
pastLongData$vhvd_int<-ifelse(pastLongData$TI6_veryHot == 1  & pastLongData$SPI6_veryDry == 1,c(1),c(0))
pastLongData$hd_int<-ifelse(pastLongData$TI6_Hot == 1  & pastLongData$SPI6_Dry == 1,c(1),c(0))


sum(pastLongData$SPI6_veryWet)
sum(pastLongData$SPI6_Wet)
sum(pastLongData$SPI6_veryDry)
sum(pastLongData$SPI6_Dry)
sum(pastLongData$TI6_veryHot)
sum(pastLongData$TI6_Hot)
sum(pastLongData$TI6_veryCold)
sum(pastLongData$TI6_Cold)
sum(pastLongData$vhvd_int)
sum(pastLongData$hd_int)

attach(pastLongData)

#makes smaller tables for easier matching
data<-data.frame(cbind(rowID,Grid,Events,EventsSpLag_lag1,Country,Factiva,IMR_lag12,GPWpop,PR_lag12,ElectPres,BrdrDistLnKm,CptlDV,DistToRd,EthLeader,
TI6_veryHot,TI6_Hot,TI6_veryCold,TI6_Cold,SPI6_veryWet,SPI6_Wet,SPI6_veryDry,SPI6_Dry,TI6_CRU,SPI6_CRU
))

data_int<-data.frame(cbind(rowID,Grid,Events,EventsSpLag_lag1,Country,Factiva,IMR_lag12,GPWpop,PR_lag12,ElectPres,BrdrDistLnKm,CptlDV,DistToRd,EthLeader,
vhvd_int,hd_int))

detach(pastLongData)



ci<-1.96
labels<-c("Very hot", "Hot", "Cold", "Very cold", "Very dry",
"Dry", "Wet", "Very wet", "Very hot and very dry", "Hot and dry")


#KEEP very dry/drought (this means leave raw temp in)
drop_vars_att_vd<- c("Events","rowID","Grid","Country","SPI6_CRU","TI6_veryHot","TI6_Hot","TI6_veryCold","TI6_Cold", "SPI6_veryWet", "SPI6_Wet","SPI6_Dry") 
mat_vd <- cem(treatment="SPI6_veryDry",data=data, drop=drop_vars_att_vd)
mat_vd
mat_vd$vars
matched_vd<-mat_vd$matched

#KEEP dry (this means leave raw temp in)
drop_vars_att_d<- c("Events","rowID","Grid","Country","SPI6_CRU","TI6_veryHot","TI6_Hot","TI6_veryCold","TI6_Cold", "SPI6_veryWet", "SPI6_Wet","SPI6_veryDry") 
mat_d <- cem(treatment="SPI6_Dry",data=data, drop=drop_vars_att_d)
mat_d
mat_d$vars
matched_d<-mat_d$matched

#KEEP wet (this means leave raw temp in)
drop_vars_att_w<- c("Events","rowID","Grid","Country","SPI6_CRU","TI6_veryHot","TI6_Hot","TI6_veryCold","TI6_Cold", "SPI6_veryWet", "SPI6_Dry","SPI6_veryDry") 
mat_w <- cem(treatment="SPI6_Wet",data=data, drop=drop_vars_att_w)
mat_w
mat_w$vars
matched_w<-mat_w$matched

#KEEP very wet (this means leave raw temp in)
drop_vars_att_vw<- c("Events","rowID","Grid","Country","SPI6_CRU","TI6_veryHot","TI6_Hot","TI6_veryCold","TI6_Cold", "SPI6_Wet", "SPI6_Dry","SPI6_veryDry") 
mat_vw <- cem(treatment="SPI6_veryWet",data=data, drop=drop_vars_att_vw)
mat_vw
mat_vw$vars
matched_vw<-mat_vw$matched

##KEEP very hot (this means leave raw precip in)
drop_vars_att_vh<- c("Events","rowID","Grid","Country","TI6_CRU","TI6_Hot","TI6_veryCold","TI6_Cold", "SPI6_veryWet", "SPI6_Wet","SPI6_Dry", "SPI6_veryDry") 
mat_vh <- cem(treatment="TI6_veryHot",data=data, drop=drop_vars_att_vh)
mat_vh
mat_vh$vars
matched_vh<-mat_vh$matched

##KEEP hot (this means leave raw precip in)
drop_vars_att_h<- c("Events","rowID","Grid","Country","TI6_CRU","TI6_veryHot","TI6_veryCold","TI6_Cold", "SPI6_veryWet", "SPI6_Wet","SPI6_Dry", "SPI6_veryDry") 
mat_h <- cem(treatment="TI6_Hot",data=data, drop=drop_vars_att_h)
mat_h
mat_h$vars
matched_h<-mat_h$matched

##KEEP cold (this means leave raw precip in)
drop_vars_att_c<- c("Events","rowID","Grid","Country","TI6_CRU","TI6_veryHot","TI6_veryCold","TI6_Hot", "SPI6_veryWet", "SPI6_Wet","SPI6_Dry", "SPI6_veryDry") 
mat_c <- cem(treatment="TI6_Cold",data=data, drop=drop_vars_att_c)
mat_c
mat_c$vars
matched_c<-mat_c$matched

##KEEP very cold (this means leave raw precip in)
drop_vars_att_vc<- c("Events","rowID","Grid","Country","TI6_CRU","TI6_veryHot","TI6_Cold","TI6_Hot", "SPI6_veryWet", "SPI6_Wet","SPI6_Dry", "SPI6_veryDry") 
mat_vc <- cem(treatment="TI6_veryCold",data=data, drop=drop_vars_att_vc)
mat_vc
mat_vc$vars
matched_vc<-mat_vc$matched

##KEEP vhvd
drop_vars_att_vhvd<- c("Events","rowID","Grid","Country","hd_int") 
mat_vhvd <- cem(treatment="vhvd_int",data=data_int, drop=drop_vars_att_vhvd)
mat_vhvd
mat_vhvd$vars
matched_vhvd<-mat_vhvd$matched

##KEEP hd
drop_vars_att_hd<- c("Events","rowID","Grid","Country","vhvd_int") 
mat_hd <- cem(treatment="hd_int",data=data_int, drop=drop_vars_att_hd)
mat_hd
mat_hd$vars
matched_hd<-mat_hd$matched

# Save off the matching - can be read in above to save time, once made
#save(mat_vh, file = "mat_vh.RData")
#save(mat_h, file = "mat_h.RData")
#save(mat_c, file = "mat_c.RData")
#save(mat_vc, file = "mat_vc.RData")
#save(mat_vd, file = "mat_vd.RData")
#save(mat_d, file = "mat_d.RData")
#save(mat_w, file = "mat_w.RData")
#save(mat_vw, file = "mat_vw.RData")
#save(mat_vhvd, file = "mat_vhvd.RData")
#save(mat_hd, file = "mat_hd.RData")


#Lines to load matched observations if already complete
#load("mat_vd.RData")
#load("mat_d.RData")
#load("mat_w.RData")
#load("mat_vw.RData")
#load("mat_vh.RData")
#load("mat_h.RData")
#load("mat_c.RData")
#load("mat_vc.RData")
#load("mat_hd.RData")
#load("mat_vhvd.RData")

#Here are imbalance statistics
vars_mvh<-c(mat_vh$vars)
mvh_imb<-imbalance(group = data$TI6_veryHot,data=data[vars_mvh])

vars_mh<-c(mat_h$vars)
mh_imb<-imbalance(group = data$TI6_Hot,data=data[vars_mh])

vars_mvc<-c(mat_vc$vars)
mvc_imb<-imbalance(group = data$TI6_veryCold,data=data[vars_mvc])

vars_mc<-c(mat_c$vars)
mc_imb<-imbalance(group = data$TI6_Cold,data=data[vars_mc])

vars_mvd<-c(mat_vd$vars)
mvd_imb<-imbalance(group = data$SPI6_veryDry,data=data[vars_mvd])

vars_md<-c(mat_d$vars)
md_imb<-imbalance(group = data$SPI6_Dry,data=data[vars_md])

vars_mvw<-c(mat_vw$vars)
mvw_imb<-imbalance(group = data$SPI6_veryWet,data=data[vars_mvw])

vars_mw<-c(mat_w$vars)
mw_imb<-imbalance(group = data$SPI6_Wet,data=data[vars_mw])

vars_vhvd<-c(mat_vhvd$vars)
mvhvd_imb<-imbalance(group = data_int$vhvd_int,data=data[vars_vhvd])

vars_hd<-c(mat_hd$vars)
mhd_imb<-imbalance(group = data_int$hd_int,data=data[vars_hd])


imb_tab<-data.frame(rbind(mvh_imb$L1,
mh_imb$L1,
mc_imb$L1,
mvc_imb$L1,
mvd_imb$L1,
md_imb$L1,
mw_imb$L1,
mvw_imb$L1,
mvhvd_imb$L1,
mhd_imb$L1))

imb_tab_final<-cbind(imb_tab$L1, imb_tab$LCS)
colnames(imb_tab_final)<-c("L1","LCS")
imb_tab_final<-data.frame(imb_tab_final)

imb_tab_final$L1 <- as.numeric(imb_tab_final$L1)
imb_tab_final$LCS <- as.numeric(imb_tab_final$LCS)

row.names(imb_tab_final)<-c("Very hot", "Hot", "Cold", "Very cold", "Very dry",
"Dry", "Wet", "Very wet", "Very hot and very dry","Hot and dry")

#This is read in above, once made 
write.csv(imb_tab_final,"imb_tab_final_int_factiva.csv")



######
#KEEP very dry/drought (this means leave raw temp in)
att_vd_lin_clustGrid<-att_clust(mat_vd,Events~SPI6_veryDry ,data=data,model="linear",clustVar = data$Grid)
att_vd_lin_clustGrid
#retrieve result
res_vd_lin_clustGrid<-att_vd_lin_clustGrid$att.model[,2]

#KEEP dry (this means leave raw temp in)
att_d_lin_clustGrid<-att_clust(mat_d,Events~SPI6_Dry ,data=data,model="linear",clustVar = data$Grid)
att_d_lin_clustGrid
#retrieve result
res_d_lin_clustGrid<-att_d_lin_clustGrid$att.model[,2]

#KEEP wet (this means leave raw temp in)
att_w_lin_clustGrid<-att_clust(mat_w,Events~SPI6_Wet ,data=data,model="linear",clustVar = data$Grid)
att_w_lin_clustGrid
#retrieve result
res_w_lin_clustGrid<-att_w_lin_clustGrid$att.model[,2]

#KEEP very wet (this means leave raw temp in)
att_vw_lin_clustGrid<-att_clust(mat_vw,Events~SPI6_veryWet ,data=data,model="linear",clustVar = data$Grid)
att_vw_lin_clustGrid
#retrieve result
res_vw_lin_clustGrid<-att_vw_lin_clustGrid$att.model[,2]

##KEEP very hot (this means leave raw precip in)
att_vh_lin_clustGrid<-att_clust(mat_vh,Events~TI6_veryHot ,data=data,model="linear",clustVar = data$Grid)
att_vh_lin_clustGrid
#retrieve result
res_vh_lin_clustGrid<-att_vh_lin_clustGrid$att.model[,2]

##KEEP hot (this means leave raw precip in)
att_h_lin_clustGrid<-att_clust(mat_h,Events~TI6_Hot ,data=data,model="linear",clustVar = data$Grid)
att_h_lin_clustGrid
#retrieve result
res_h_lin_clustGrid<-att_h_lin_clustGrid$att.model[,2]

##KEEP cold (this means leave raw precip in)
att_c_lin_clustGrid<-att_clust(mat_c,Events~TI6_Cold ,data=data,model="linear",clustVar = data$Grid)
att_c_lin_clustGrid
#retrieve result
res_c_lin_clustGrid<-att_c_lin_clustGrid$att.model[,2]

##KEEP very cold (this means leave raw precip in)
att_vc_lin_clustGrid<-att_clust(mat_vc,Events~TI6_veryCold ,data=data,model="linear",clustVar = data$Grid)
att_vc_lin_clustGrid
#retrieve result
res_vc_lin_clustGrid<-att_vc_lin_clustGrid$att.model[,2]

##KEEP vhvd
att_vhvd_lin_clustGrid<-att_clust(mat_vhvd,Events~vhvd_int ,data=data_int,model="linear",clustVar = data$Grid)
att_vhvd_lin_clustGrid
#retrieve result
res_vhvd_lin_clustGrid<-att_vhvd_lin_clustGrid$att.model[,2]

##KEEP hd
att_hd_lin_clustGrid<-att_clust(mat_hd,Events~hd_int ,data=data_int,model="linear",clustVar = data$Grid)
att_hd_lin_clustGrid
#retrieve result
res_hd_lin_clustGrid<-att_hd_lin_clustGrid$att.model[,2]

results_lin_clustGrid<-rbind (res_vh_lin_clustGrid,res_h_lin_clustGrid,res_c_lin_clustGrid,res_vc_lin_clustGrid,res_vd_lin_clustGrid,res_d_lin_clustGrid,res_w_lin_clustGrid,res_vw_lin_clustGrid,res_vhvd_lin_clustGrid,res_hd_lin_clustGrid)

write.csv(results_lin_clustGrid, "prelim_match_model_lin_clustGrid_factor.csv")

ci<-1.96
labels<-c("Very hot", "Hot", "Cold", "Very cold", "Very dry",
"Dry", "Wet", "Very wet", "Very hot and very dry", "Hot and dry")

#lines to save off att
#save(att_vh_lin_clustGrid, file = "att_vh_lin_clustGrid.RData")
#save(att_h_lin_clustGrid, file = "att_h_lin_clustGrid.RData")
#save(att_c_lin_clustGrid, file = "att_c_lin_clustGrid.RData")
#save(att_vc_lin_clustGrid, file = "att_vc_lin_clustGrid.RData")
#save(att_vw_lin_clustGrid, file = "att_vw_lin_clustGrid.RData")
#save(att_w_lin_clustGrid, file = "att_w_lin_clustGrid.RData")
#save(att_d_lin_clustGrid, file = "att_d_lin_clustGrid.RData")
#save(att_vd_lin_clustGrid, file = "att_vd_lin_clustGrid.RData")
#save(att_vhvd_lin_clustGrid, file = "att_vhvd_lin_clustGrid.RData")
#save(att_hd_lin_clustGrid, file = "att_hd_lin_clustGrid.RData")


#ci<-1.64

# m1 ###################
m1_for_ci_lin_clustGrid <-att_vh_lin_clustGrid$att.model[,2]
m1_se_lin_clustGrid<-m1_for_ci_lin_clustGrid[2]
m1_est_lin_clustGrid<-m1_for_ci_lin_clustGrid[1]
m1_ci_lin_clustGrid<- m1_se_lin_clustGrid*ci
high_m1_lin_clustGrid <- m1_est_lin_clustGrid + m1_ci_lin_clustGrid
low_m1_lin_clustGrid <- m1_est_lin_clustGrid - m1_ci_lin_clustGrid

# m2 ###################
m2_for_ci_lin_clustGrid <-att_h_lin_clustGrid$att.model[,2]
m2_se_lin_clustGrid<-m2_for_ci_lin_clustGrid[2]
m2_est_lin_clustGrid<-m2_for_ci_lin_clustGrid[1]
m2_ci_lin_clustGrid<- m2_se_lin_clustGrid*ci
high_m2_lin_clustGrid <- m2_est_lin_clustGrid + m2_ci_lin_clustGrid
low_m2_lin_clustGrid <- m2_est_lin_clustGrid - m2_ci_lin_clustGrid

# m3 ###################
m3_for_ci_lin_clustGrid <-att_c_lin_clustGrid$att.model[,2]
m3_se_lin_clustGrid<-m3_for_ci_lin_clustGrid[2]
m3_est_lin_clustGrid<-m3_for_ci_lin_clustGrid[1]
m3_ci_lin_clustGrid<- m3_se_lin_clustGrid*ci
high_m3_lin_clustGrid <- m3_est_lin_clustGrid + m3_ci_lin_clustGrid
low_m3_lin_clustGrid <- m3_est_lin_clustGrid - m3_ci_lin_clustGrid

# m4 ###################
m4_for_ci_lin_clustGrid <-att_vc_lin_clustGrid$att.model[,2]
m4_se_lin_clustGrid<-m4_for_ci_lin_clustGrid[2]
m4_est_lin_clustGrid<-m4_for_ci_lin_clustGrid[1]
m4_ci_lin_clustGrid<- m4_se_lin_clustGrid*ci
high_m4_lin_clustGrid <- m4_est_lin_clustGrid + m4_ci_lin_clustGrid
low_m4_lin_clustGrid <- m4_est_lin_clustGrid - m4_ci_lin_clustGrid

# m5 ###################
m5_for_ci_lin_clustGrid <-att_vd_lin_clustGrid$att.model[,2]
m5_se_lin_clustGrid<-m5_for_ci_lin_clustGrid[2]
m5_est_lin_clustGrid<-m5_for_ci_lin_clustGrid[1]
m5_ci_lin_clustGrid<- m5_se_lin_clustGrid*ci
high_m5_lin_clustGrid <- m5_est_lin_clustGrid + m5_ci_lin_clustGrid
low_m5_lin_clustGrid <- m5_est_lin_clustGrid - m5_ci_lin_clustGrid


# m6 ###################
m6_for_ci_lin_clustGrid <-att_d_lin_clustGrid$att.model[,2]
m6_se_lin_clustGrid<-m6_for_ci_lin_clustGrid[2]
m6_est_lin_clustGrid<-m6_for_ci_lin_clustGrid[1]
m6_ci_lin_clustGrid<- m6_se_lin_clustGrid*ci
high_m6_lin_clustGrid <- m6_est_lin_clustGrid + m6_ci_lin_clustGrid
low_m6_lin_clustGrid<- m6_est_lin_clustGrid - m6_ci_lin_clustGrid

# m7 ###################
m7_for_ci_lin_clustGrid <-att_w_lin_clustGrid$att.model[,2]
m7_se_lin_clustGrid<-m7_for_ci_lin_clustGrid[2]
m7_est_lin_clustGrid<-m7_for_ci_lin_clustGrid[1]
m7_ci_lin_clustGrid<- m7_se_lin_clustGrid*ci
high_m7_lin_clustGrid <- m7_est_lin_clustGrid + m7_ci_lin_clustGrid
low_m7_lin_clustGrid <- m7_est_lin_clustGrid - m7_ci_lin_clustGrid


# m8 ###################
m8_for_ci_lin_clustGrid <-att_vw_lin_clustGrid$att.model[,2]
m8_se_lin_clustGrid<-m8_for_ci_lin_clustGrid[2]
m8_est_lin_clustGrid<-m8_for_ci_lin_clustGrid[1]
m8_ci_lin_clustGrid<- m8_se_lin_clustGrid*ci
high_m8_lin_clustGrid <- m8_est_lin_clustGrid + m8_ci_lin_clustGrid
low_m8_lin_clustGrid <- m8_est_lin_clustGrid- m8_ci_lin_clustGrid

#m9 ######################
m9_for_ci_lin_clustGrid <-att_vhvd_lin_clustGrid$att.model[,2]
m9_se_lin_clustGrid<-m9_for_ci_lin_clustGrid[2]
m9_est_lin_clustGrid<-m9_for_ci_lin_clustGrid[1]
m9_ci_lin_clustGrid<- m9_se_lin_clustGrid*ci
high_m9_lin_clustGrid <- m9_est_lin_clustGrid + m9_ci_lin_clustGrid
low_m9_lin_clustGrid<- m9_est_lin_clustGrid - m9_ci_lin_clustGrid

#m10 ######################
m10_for_ci_lin_clustGrid <-att_hd_lin_clustGrid$att.model[,2]
m10_se_lin_clustGrid<-m10_for_ci_lin_clustGrid[2]
m10_est_lin_clustGrid<-m10_for_ci_lin_clustGrid[1]
m10_ci_lin_clustGrid<- m10_se_lin_clustGrid*ci
high_m10_lin_clustGrid <- m10_est_lin_clustGrid + m10_ci_lin_clustGrid
low_m10_lin_clustGrid <- m10_est_lin_clustGrid - m10_ci_lin_clustGrid


#####plot 

#get number of obs matched 


matched_vd<-mat_vd$matched
matched_d<-mat_d$matched
matched_w<-mat_w$matched
matched_vw<-mat_vw$matched
matched_vh<-mat_vh$matched
matched_h<-mat_h$matched
matched_c<-mat_c$matched
matched_vc<-mat_vc$matched
matched_vhvd<-mat_vhvd$matched
matched_hd<-mat_hd$matched

vh_matched<-data.frame(table(matched_vh)[2])
h_matched<-data.frame(table(matched_h)[2])
c_matched<-data.frame(table(matched_c)[2])
vc_matched<-data.frame(table(matched_vc)[2])

vd_matched<-data.frame(table(matched_vd)[2])
d_matched<-data.frame(table(matched_d)[2])
w_matched<-data.frame(table(matched_w)[2])
vw_matched<-data.frame(table(matched_vw)[2])

vhvd_matched<-data.frame(table(matched_vhvd)[2])
hd_matched<-data.frame(table(matched_hd)[2])

matched_ns<-c(vh_matched[,1],h_matched[,1],c_matched[,1],
vc_matched[,1],vd_matched[,1],d_matched[,1],
w_matched[,1], vw_matched[,1], vhvd_matched[,1],hd_matched[,1])

labels_test<-paste (labels,matched_ns, sep = "\n N=")

##### plot figure
pdf("lin_clust_196_GRID.pdf",10,6)
par(mar=c(6, 11, 6, 15))

plot(m1_est_lin_clustGrid,10, pch=18, cex = .25, xlim = c(-.03,.01), ylim = c(0,10), 
yaxt = 'n', xlab="Treatment effect on the treated \n (Events per grid/month)", ylab = '  ',
main = "Weather indicator effects upon conflict \n (Grid clustered SEs)"
)

abline(v = 0, col = "gray50", lty=2)
axis(2, at = c(10:1), labels = labels, las=2, cex.axis = 1, font = 2)

#m1
arrows (low_m1_lin_clustGrid,10,high_m1_lin_clustGrid,10,length = 0,lwd=3, col = "firebrick3")
points(m1_est_lin_clustGrid,10,pch = 16,cex=1,col = "firebrick3")
text(m1_est_lin_clustGrid,9.75, round(m1_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m2
arrows (low_m2_lin_clustGrid,9,high_m2_lin_clustGrid,9,length = 0,lwd=3, col = "firebrick3")
points(m2_est_lin_clustGrid,9,pch = 16,cex=1,col = "firebrick3")
text(m2_est_lin_clustGrid,8.75, round(m2_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m3
arrows (low_m3_lin_clustGrid,8,high_m3_lin_clustGrid,8,length = 0,lwd=3, col = "firebrick3")
points(m3_est_lin_clustGrid,8,pch = 16,cex=1,col = "firebrick3")
text(m3_est_lin_clustGrid,7.75, round(m3_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m4
arrows (low_m4_lin_clustGrid,7,high_m4_lin_clustGrid,7,length = 0,lwd=3, col = "firebrick3")
points(m4_est_lin_clustGrid,7,pch = 16,cex=1,col = "firebrick3")
text(m4_est_lin_clustGrid,6.75, round(m4_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m5
arrows (low_m5_lin_clustGrid,6,high_m5_lin_clustGrid,6,length = 0,lwd=3, col = "firebrick3")
points(m5_est_lin_clustGrid,6,pch = 16,cex=1,col = "firebrick3")
text(m5_est_lin_clustGrid,5.75, round(m5_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m6
arrows (low_m6_lin_clustGrid,5,high_m6_lin_clustGrid,5,length = 0,lwd=3, col = "firebrick3")
points(m6_est_lin_clustGrid,5,pch = 16,cex=1,col = "firebrick3")
text(m6_est_lin_clustGrid,4.75, round(m6_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m7 
arrows (low_m7_lin_clustGrid,4,high_m7_lin_clustGrid,4,length = 0,lwd=3, col = "firebrick3")
points(m7_est_lin_clustGrid,4,pch = 16,cex=1,col = "firebrick3")
text(m7_est_lin_clustGrid,3.75, round(m7_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m8
arrows (low_m8_lin_clustGrid,3,high_m8_lin_clustGrid,3,length = 0,lwd=3, col = "firebrick3")
points(m8_est_lin_clustGrid,3,pch = 16,cex=1,col = "firebrick3")
text(m8_est_lin_clustGrid,2.75, round(m8_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m9
arrows (low_m9_lin_clustGrid,2,high_m9_lin_clustGrid,2,length = 0,lwd=3, col = "firebrick3")
points(m9_est_lin_clustGrid,2,pch = 16,cex=1,col = "firebrick3")
text(m9_est_lin_clustGrid,1.75, round(m9_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

#m10
arrows (low_m10_lin_clustGrid,1,high_m10_lin_clustGrid,1,length = 0,lwd=3, col = "firebrick3")
points(m10_est_lin_clustGrid,1,pch = 16,cex=1,col = "firebrick3")
text(m10_est_lin_clustGrid,.75, round(m10_est_lin_clustGrid,digits=4), col = "black", cex = 1, font = 2)

L1<-as.numeric(imb_tab_final$L1)
L1<-round (L1, digits= 5)
L1 <- paste("; L1 = ", L1, "; ")
LCS <- as.numeric (imb_tab_final$LCS)
LCS <- round (LCS, digits=5)
LCS <- paste("LCS = ", LCS, ")")

all_balance <- paste (L1,LCS, sep = "")

matched_n<-paste("(N = ", matched_ns, all_balance, sep = "")

### HERE concatonate a "match L1 = " into the character string
axis(4, at = c(10:1), labels = matched_n, font =3, las=2, xaxt = 'n',tick = FALSE, cex.axis = .75)

dev.off()
