#for VAC only - 

#load the matched data you made
load("mat_vd.RData")
load("mat_d.RData")
load("mat_w.RData")
load("mat_vw.RData")
load("mat_vh.RData")
load("mat_h.RData")
load("mat_c.RData")
load("mat_vc.RData")
load("mat_hd.RData")
load("mat_vhvd.RData")

#load the imbalance table from before (used in the figure)
imb_tab_final<-read.csv("imb_tab_final_int_factiva.csv")


#load the matched data N table from before (used in the figure)
matched_ns<-read.csv("matched_ns.csv")
matched_ns<-matched_ns$x

# make att cluster function
att_clust <- function (obj, formula, data, model = "linear", extrapolate = FALSE, 

    ntree = 2000, clustVar = NULL) 

{

    mod.type <- NULL

    mod <- NULL

    if ((class(obj)[1] != "cem.match") && (class(obj)[1] != "cem.match.list")) 

        stop("Argument `obj' must be a `cem.match' or `cem.match.list' object")

    mods <- c("linear", "lm", "lme", "linear-RE", "logit", "logistic", 

        "rf", "forest")

    if (!(model %in% mods)) 

        stop(sprintf("model `%s' not yet implemented", model))

    if (model %in% c("lm", "linear")) {

        mod <- "lm"

        mod.type <- "Linear regression model"

    }

    if (model %in% c("lme", "linear-RE")) {

        mod <- "lme"

        mod.type <- "Linear random effect model"

    }

    if (model %in% c("forest", "rf")) {

        mod <- "randomForest"

        mod.type <- "Random forest model"

    }

    if (model %in% c("logit", "logistic")) {

        mod <- "glm"

        mod.type <- "Logistic model"

    }

    random.cem <- NULL

    random.all <- NULL

    ranef.cem <- NULL

    ranef.all <- NULL

    reg.cem <- NULL

    reg.all <- NULL

    rf.cem <- NULL

    TE <- NULL

    control = lmeControl(maxIter = 1000, opt = "optim")

    if (class(obj)[1] == "cem.match") {

        if (mod == "randomForest") {

            require(randomForest, quietly = TRUE)

            out <- do.call(mod, list(formula = formula, data = data, 

                subset = obj$matched == TRUE & obj$groups == 

                  obj$g.names[1], ntree = ntree))

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data)

            TEi <- data[, response] - prd

            if (extrapolate) {

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  mean(TEi[idt])

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                ww <- table(obj$strata, obj$groups)[, 2]

                w.coef <- weighted.mean(TE, ww, na.rm = TRUE)

                idx <- which(is.na(TE))

                if (length(idx) > 0) 

                  TE <- TE[-idx]

                rf.cem <- matrix(NA, 4, 1)

                v0 <- var(data[obj$groups == obj$g.names[2], 

                  response])

                v1 <- var(prd[obj$groups == obj$g.names[2]])

            }

            else {

                g <- function(i) {

                  idt <- which(obj$mstrata == i & obj$groups == 

                    obj$g.names[2])

                  mean(TEi[idt])

                }

                mstrata <- na.omit(unique(obj$mstrata))

                TE <- sapply(mstrata, g)

                names(TE) <- mstrata

                ww <- table(obj$mstrata, obj$groups)[, 2]

                w.coef <- weighted.mean(TE, ww, na.rm = TRUE)

                idx <- which(is.na(TE))

                if (length(idx) > 0) 

                  TE <- TE[-idx]

                rf.cem <- matrix(NA, 4, 1)

                v0 <- var(data[obj$matched == TRUE & obj$groups == 

                  obj$g.names[2], response])

                v1 <- var(prd[obj$matched == TRUE & obj$groups == 

                  obj$g.names[2]])

            }

            dimnames(rf.cem) <- list(c("Estimate", "Std. Error", 

                "t value", "p-value"), obj$treatment)

            rf.cem["Estimate", ] <- w.coef

            rf.cem["Std. Error", ] <- sqrt((v1 + v0) * sum(ww^2)/sum(ww)^2)

            rf.cem["t value", ] <- rf.cem["Estimate", ]/rf.cem["Std. Error", 

                ]

            rf.cem["p-value", ] <- 2 * (1 - pnorm(rf.cem["t value", 

                ]))

            att.model <- rf.cem

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "lme") {

            require(nlme, quietly = TRUE)

            data1 <- data

            data1$allID <- factor(obj$strata)

            data1$cemID <- factor(obj$mstrata)

            data1$matched <- obj$matched

            matched <- obj$matched

            f1 <- formula(sprintf(" ~ %s | allID", obj$treatment))

            f2 <- formula(sprintf(" ~ %s | cemID", obj$treatment))

            if (extrapolate) {

                rand.try <- try(lme(update(formula, ~. - cemID - 

                  allID - matched), data = data1, random = f1, 

                  keep.data = FALSE, control = control), silent = TRUE)

                if (class(rand.try) == "try-error") {

                  cat("\nCannot estimate the random effects model for the complete data set\n")

                }

                else {

                  rand.all <- rand.try

                  random.all <- t(summary(rand.all)$tTable)

                  rand.cf <- coef(rand.all)

                  ww <- table(obj$strata, obj$groups)[, 2]

                  cf.idx <- match(rownames(rand.cf), names(ww))

                  rownames(random.all) <- c("Estimate", "Std. Error", 

                    "DF", "t value", "p-value")

                  w.coef <- apply(rand.cf, 2, function(x) weighted.mean(x, 

                    w = ww[cf.idx]))

                  random.all["Estimate", ] <- w.coef

                  random.all["Std. Error", ] <- random.all["Std. Error", 

                    ] * sqrt(sum(ww^2)/sum(ww)^2)

                  random.all["t value", ] <- random.all["Estimate", 

                    ]/random.all["Std. Error", ]

                  random.all["p-value", ] <- 2 * (1 - pnorm(random.all["t value", 

                    ]))

                  att.model <- random.all

                  TE <- rand.cf[, obj$treatment]

                  names(TE) <- rownames(rand.cf)

                }

            }

            else {

                rand.try <- try(lme(update(formula, ~. - cemID - 

                  allID - matched), data = data1, random = f2, 

                  subset = matched == TRUE, keep.data = FALSE, 

                  control = control), silent = TRUE)

                if (class(rand.try) == "try-error") {

                  cat("\nCannot estimate the random effects model for the CEM matched subsample\n")

                }

                else {

                  rand.cem <- rand.try

                  random.cem <- t(summary(rand.cem)$tTable)

                  rand.cf <- coef(rand.cem)

                  ww <- table(obj$mstrata, obj$groups)[, 2]

                  cf.idx <- match(rownames(rand.cf), names(ww))

                  rownames(random.cem) <- c("Estimate", "Std. Error", 

                    "DF", "t value", "p-value")

                  w.coef <- apply(rand.cf, 2, function(x) weighted.mean(x, 

                    w = ww[cf.idx]))

                  random.cem["Estimate", ] <- w.coef

                  random.cem["Std. Error", ] <- random.cem["Std. Error", 

                    ] * sqrt(sum(ww^2)/sum(ww)^2)

                  random.cem["t value", ] <- random.cem["Estimate", 

                    ]/random.cem["Std. Error", ]

                  random.cem["p-value", ] <- 2 * (1 - pnorm(random.cem["t value", 

                    ]))

                  ranef.cem <- random.effects(rand.cem)

                  att.model <- random.cem

                  TE <- rand.cf[, obj$treatment]

                  names(TE) <- rownames(rand.cf)

                }

            }

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "lm") {

            out <- do.call(mod, list(formula = formula, data = data, 

                weights = obj$w))

            fit <- fitted(out)

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data)

            TEi <- data[, response] - prd

            g <- function(i) {

                idt <- which(obj$mstrata == i & obj$groups == 

                  obj$g.names[2])

                mean(TEi[idt])

            }

            mstrata <- na.omit(unique(obj$mstrata))

            TE <- sapply(mstrata, g)

            names(TE) <- mstrata

            idx <- which(is.na(TE))

            if (length(idx) > 0) 

                TE <- TE[-idx]

			#browser()

			# FDWW: calculate grid-clustered errors here instead

			if (length(clustVar) > 0) { print("clustered std errs being calculated for lm model")

				reg.cem <- t(clustErrs(out, clustVar))

				#rownames(reg.cem) <- c("Estimate", "Clust. Std. Err.", "Clust. z value", "Clust. Pr(>|z|)")	# don't change these names -- it interferes with summary/print functions

			} else {

				reg.cem <- t(summary(out)$coefficients)

			}

			rownames(reg.cem) <- c("Estimate", "Std. Error", 

                "t value", "p-value")

            att.model <- reg.cem

            if (extrapolate) {

                idx2 <- which(!obj$matched & obj$groups == obj$g.names[2])

                f3 <- formula(sprintf(" ~  . -%s ", obj$treatment))

                f4 <- update(formula, f3)

                tmp.data <- data[idx2, ]

                tmp.data[obj$treatment] <- 0

                y1 <- predict(out, newdata = tmp.data)

                response <- all.vars(f4)[attr(terms(formula), 

                  "response")]

                tmp <- t.test(y1, data[idx2, response])

                att4 <- diff(tmp$estimate)

                att4.serr <- abs(diff(tmp$estimate)/tmp$statistic)

                p <- obj$tab[2, 2]/obj$tab[1, 2]

                att4 <- (1 - p) * att4 + p * reg.cem["Estimate", 

                  obj$treatment]

                reg.all <- matrix(NA, 4, 1)

                rownames(reg.all) <- rownames(reg.cem)

                colnames(reg.all) <- obj$treatment

                reg.all["Estimate", 1] <- att4

                reg.all["Std. Error", 1] <- sqrt(p^2 * reg.cem["Std. Error", 

                  obj$treatment]^2 + (1 - p)^2 * att4.serr^2)

                reg.all["t value", 1] <- att4/att4.serr

                reg.all["p-value", 1] <- 2 * (1 - pnorm(att4/att4.serr))

                reg.cem <- NULL

                att.model <- reg.all

                TE <- NULL

                fit <- fitted(out)

                tmp.data <- data

                tmp.data[obj$treatment] <- 0

                prd <- predict(out, tmp.data)

                TEi <- data[, response] - prd

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  if (length(idt) > 0) 

                    return(mean(TEi[idt]))

                  return(NA)

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                idx <- which(is.na(TE))

                TE <- TE[-idx]

            }

			# add lm regression object to returned list (lmObj = out)

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE, lmObj = out)

            class(out) <- "cem.att"

            return(out)

        }

        if (mod == "glm") {

            out <- do.call(mod, list(formula = formula, data = data, 

                weights = obj$w, family = "binomial"))

            fit <- fitted(out)

            response <- all.vars(formula)[attr(terms(formula), 

                "response")]

            tmp.data <- data

            tmp.data[, obj$treatment] <- 0

            prd <- predict(out, tmp.data, type = "response")

            TEi <- data[, response] - prd

            g <- function(i) {

                idt <- which(obj$mstrata == i & obj$groups == 

                  obj$g.names[2])

                mean(TEi[idt])

            }

            mstrata <- na.omit(unique(obj$mstrata))

            TE <- sapply(mstrata, g)

            names(TE) <- mstrata

            idx <- which(is.na(TE))

            if (length(idx) > 0) 

                TE <- TE[-idx]

            reg.cem <- t(summary(out)$coefficients)

			# TODO: calculate grid clustered std errors for logit models?

            rownames(reg.cem) <- c("Estimate", "Std. Error", 

                "t value", "p-value")

            att.model <- reg.cem

            if (extrapolate) {

                idx2 <- which(!obj$matched & obj$groups == obj$g.names[2])

                f3 <- formula(sprintf(" ~  . -%s ", obj$treatment))

                f4 <- update(formula, f3)

                tmp.data <- data[idx2, ]

                tmp.data[obj$treatment] <- 0

                y1 <- predict(out, newdata = tmp.data, type = "response")

                response <- all.vars(f4)[attr(terms(formula), 

                  "response")]

                tmp <- t.test(y1, data[idx2, response])

                att4 <- diff(tmp$estimate)

                att4.serr <- abs(diff(tmp$estimate)/tmp$statistic)

                p <- obj$tab[2, 2]/obj$tab[1, 2]

                att4 <- (1 - p) * att4 + p * reg.cem["Estimate", 

                  obj$treatment]

                reg.all <- matrix(NA, 4, 1)

                rownames(reg.all) <- rownames(reg.cem)

                colnames(reg.all) <- obj$treatment

                reg.all["Estimate", 1] <- att4

                reg.all["Std. Error", 1] <- sqrt(p^2 * reg.cem["Std. Error", 

                  obj$treatment]^2 + (1 - p)^2 * att4.serr^2)

                reg.all["t value", 1] <- att4/att4.serr

                reg.all["p-value", 1] <- 2 * (1 - pnorm(att4/att4.serr))

                reg.cem <- NULL

                att.model <- reg.all

                TE <- NULL

                tmp.data <- data

                tmp.data[obj$treatment] <- 0

                prd <- predict(out, tmp.data, type = "response")

                TEi <- data[, response] - prd

                g <- function(i) {

                  idt <- which(obj$strata == i & obj$groups == 

                    obj$g.names[2])

                  if (length(idt) > 0) 

                    return(mean(TEi[idt]))

                  return(NA)

                }

                strata <- na.omit(unique(obj$strata))

                TE <- sapply(strata, g)

                names(TE) <- strata

                idx <- which(is.na(TE))

                TE <- TE[-idx]

            }

            out <- list(att.model = att.model, tab = obj$tab, 

                treatment = obj$treatment, extrapolate = extrapolate, 

                mod.type = mod.type, TE = TE)

            class(out) <- "cem.att"

            return(out)

        }

    }

    if (class(data) != "list") 

        stop("Argument `data' must be a list of `data.frame's")

    n.cems <- length(obj) - 1

    if (length(data) != n.cems) 

        stop("lengths of `cem.match.list' object and `data' do not match")

    est <- vector(n.cems, mode = "list")

    for (i in 1:n.cems) {

        out <- att(obj[[i]], formula = formula, data = data[[i]], 

            model = model, extrapolate = extrapolate)

        est[[i]] <- out

    }

    ncoef <- NCOL(est[[1]])

    qoi <- numeric(ncoef)

    seq <- numeric(ncoef)

    for (i in 1:n.cems) {

        att.m <- est[[i]]$att.model

        qoi <- qoi + att.m["Estimate", ]

        seq <- seq + att.m["Std. Error", ]^2

    }

    qoi <- qoi/n.cems

    seq <- seq/n.cems

    s2 <- numeric(ncoef)

    for (i in 1:n.cems) {

        att.m <- est[[i]]$att.model

        s2 <- s2 + (att.m["Estimate", ] - qoi)^2

    }

    s2 <- s2/(n.cems - 1)

    S <- sqrt(seq + s2 * (1 + 1/n.cems))

    TE <- vector(n.cems, mode = "list")

    for (i in 1:n.cems) TE[[i]] <- est[[i]]$TE

    att.model <- rbind(qoi, S)

    att.model <- rbind(att.model, att.model[1, ]/att.model[2, 

        ])

    att.model <- rbind(att.model, 2 * (1 - pnorm(att.model[3, 

        ])))

    if (colnames(att.model)[1] == "qoi") 

        colnames(att.model)[1] <- obj[[1]]$treatment

    rownames(att.model) <- c("Estimate", "Std. Error", "t value", 

        "p-value")

    out <- list(mult = est, att.model = att.model, treatment = obj[[1]]$treatment, 

        extrapolate = extrapolate, mod.type = mod.type, TE = TE)

    class(out) <- "cem.att"

    out

}



baseDir<-" ... your directory... "

library (cem)

setwd(baseDir)

source(paste(baseDir, "LoadOneDegGridMonthDataToAndrew.R", sep=""))
source(paste(baseDir, "SharedClimateModelFunctions.R", sep=""))

names(pastLongData)
dim(pastLongData)


#vars we want:

pastLongData$TI6_veryHot <- ifelse (pastLongData$TI6_CRU >= 2, c(1), c(0))
pastLongData$TI6_Hot<- ifelse (pastLongData$TI6_CRU >= 1, c(1), c(0))
pastLongData$TI6_veryCold <- ifelse (pastLongData$TI6_CRU <= -2, c(1), c(0))
pastLongData$TI6_Cold<- ifelse (pastLongData$TI6_CRU <= -1, c(1), c(0))

pastLongData$SPI6_veryWet <- ifelse (pastLongData$SPI6_CRU >= 2, c(1), c(0))
pastLongData$SPI6_Wet<- ifelse (pastLongData$SPI6_CRU >= 1, c(1), c(0))
pastLongData$SPI6_veryDry <- ifelse (pastLongData$SPI6_CRU <= -2, c(1), c(0))
pastLongData$SPI6_Dry<- ifelse (pastLongData$SPI6_CRU <= -1, c(1), c(0))


pastLongData$vhvd_int<-ifelse(pastLongData$TI6_veryHot == 1  & pastLongData$SPI6_veryDry == 1,c(1),c(0))
pastLongData$hd_int<-ifelse(pastLongData$TI6_Hot == 1  & pastLongData$SPI6_Dry == 1,c(1),c(0))


sum(pastLongData$SPI6_veryWet)
sum(pastLongData$SPI6_Wet)
sum(pastLongData$SPI6_veryDry)
sum(pastLongData$SPI6_Dry)

sum(pastLongData$TI6_veryHot)
sum(pastLongData$TI6_Hot)
sum(pastLongData$TI6_veryCold)
sum(pastLongData$TI6_Cold)

sum(pastLongData$vhvd_int)
sum(pastLongData$hd_int)

attach(pastLongData)

###################### NOTICE - BELOW SWITCHES 'EVENTS TO EVENTSCIVS
data<-data.frame(cbind(rowID,Grid,EventCivs,EventsSpLag_lag1,Country,Factiva,IMR_lag12,GPWpop,PR_lag12,ElectPres,BrdrDistLnKm,CptlDV,DistToRd,EthLeader,
TI6_veryHot,TI6_Hot,TI6_veryCold,TI6_Cold,SPI6_veryWet,SPI6_Wet,SPI6_veryDry,SPI6_Dry,TI6_CRU,SPI6_CRU
))


data_int<-data.frame(cbind(rowID,Grid,EventCivs,EventsSpLag_lag1,Country,Factiva,IMR_lag12,GPWpop,PR_lag12,ElectPres,BrdrDistLnKm,CptlDV,DistToRd,EthLeader,
vhvd_int,hd_int))

detach(pastLongData)


ci<-1.96
labels<-c("Very hot", "Hot", "Cold", "Very cold", "Very dry",
"Dry", "Wet", "Very wet", "Very hot and very dry", "Hot and dry")


#KEEP very dry/drought (this means leave raw temp in)
att_vd_lin_clust<-att_clust(mat_vd,EventCivs~SPI6_veryDry ,data=data,model="linear",clustVar = data$Grid)
att_vd_lin_clust
#retrieve result
res_vd_lin_clust<-att_vd_lin_clust$att.model[,2]

#KEEP dry (this means leave raw temp in)
att_d_lin_clust<-att_clust(mat_d,EventCivs~SPI6_Dry ,data=data,model="linear",clustVar = data$Grid)
att_d_lin_clust
#retrieve result
res_d_lin_clust<-att_d_lin_clust$att.model[,2]

#KEEP wet (this means leave raw temp in)
att_w_lin_clust<-att_clust(mat_w,EventCivs~SPI6_Wet ,data=data,model="linear",clustVar = data$Grid)
att_w_lin_clust
#retrieve result
res_w_lin_clust<-att_w_lin_clust$att.model[,2]

#KEEP very wet (this means leave raw temp in)
att_vw_lin_clust<-att_clust(mat_vw,EventCivs~SPI6_veryWet ,data=data,model="linear",clustVar = data$Grid)
att_vw_lin_clust
#retrieve result
res_vw_lin_clust<-att_vw_lin_clust$att.model[,2]

##KEEP very hot (this means leave raw precip in)
att_vh_lin_clust<-att_clust(mat_vh,EventCivs~TI6_veryHot ,data=data,model="linear",clustVar = data$Grid)
att_vh_lin_clust
#retrieve result
res_vh_lin_clust<-att_vh_lin_clust$att.model[,2]

##KEEP hot (this means leave raw precip in)
att_h_lin_clust<-att_clust(mat_h,EventCivs~TI6_Hot ,data=data,model="linear",clustVar = data$Grid)
att_h_lin_clust
#retrieve result
res_h_lin_clust<-att_h_lin_clust$att.model[,2]

##KEEP cold (this means leave raw precip in)
att_c_lin_clust<-att_clust(mat_c,EventCivs~TI6_Cold ,data=data,model="linear",clustVar = data$Grid)
att_c_lin_clust
#retrieve result
res_c_lin_clust<-att_c_lin_clust$att.model[,2]

##KEEP very cold (this means leave raw precip in)
att_vc_lin_clust<-att_clust(mat_vc,EventCivs~TI6_veryCold ,data=data,model="linear",clustVar = data$Grid)
att_vc_lin_clust
#retrieve result
res_vc_lin_clust<-att_vc_lin_clust$att.model[,2]

##KEEP vhvd
att_vhvd_lin_clust<-att_clust(mat_vhvd,EventCivs~vhvd_int ,data=data_int,model="linear",clustVar = data$Grid)
att_vhvd_lin_clust
#retrieve result
res_vhvd_lin_clust<-att_vhvd_lin_clust$att.model[,2]

##KEEP hd
att_hd_lin_clust<-att_clust(mat_hd,EventCivs~hd_int ,data=data_int,model="linear",clustVar = data$Grid)
att_hd_lin_clust
#retrieve result
res_hd_lin_clust<-att_hd_lin_clust$att.model[,2]

results_lin_clust<-rbind (res_vh_lin_clust,res_h_lin_clust,res_c_lin_clust,res_vc_lin_clust,res_vd_lin_clust,res_d_lin_clust,res_w_lin_clust,res_vw_lin_clust,res_vhvd_lin_clust,res_hd_lin_clust)

results_lin_clust


# m1 ###################
m1_for_ci_lin_clust <-att_vh_lin_clust$att.model[,2]
m1_se_lin_clust<-m1_for_ci_lin_clust[2]
m1_est_lin_clust<-m1_for_ci_lin_clust[1]
m1_ci_lin_clust<- m1_se_lin_clust*ci
high_m1_lin_clust <- m1_est_lin_clust + m1_ci_lin_clust
low_m1_lin_clust <- m1_est_lin_clust - m1_ci_lin_clust

# m2 ###################
m2_for_ci_lin_clust <-att_h_lin_clust$att.model[,2]
m2_se_lin_clust<-m2_for_ci_lin_clust[2]
m2_est_lin_clust<-m2_for_ci_lin_clust[1]
m2_ci_lin_clust<- m2_se_lin_clust*ci
high_m2_lin_clust <- m2_est_lin_clust + m2_ci_lin_clust
low_m2_lin_clust <- m2_est_lin_clust - m2_ci_lin_clust

# m3 ###################
m3_for_ci_lin_clust <-att_c_lin_clust$att.model[,2]
m3_se_lin_clust<-m3_for_ci_lin_clust[2]
m3_est_lin_clust<-m3_for_ci_lin_clust[1]
m3_ci_lin_clust<- m3_se_lin_clust*ci
high_m3_lin_clust <- m3_est_lin_clust + m3_ci_lin_clust
low_m3_lin_clust <- m3_est_lin_clust - m3_ci_lin_clust

# m4 ###################
m4_for_ci_lin_clust <-att_vc_lin_clust$att.model[,2]
m4_se_lin_clust<-m4_for_ci_lin_clust[2]
m4_est_lin_clust<-m4_for_ci_lin_clust[1]
m4_ci_lin_clust<- m4_se_lin_clust*ci
high_m4_lin_clust <- m4_est_lin_clust + m4_ci_lin_clust
low_m4_lin_clust <- m4_est_lin_clust - m4_ci_lin_clust

# m5 ###################
m5_for_ci_lin_clust <-att_vd_lin_clust$att.model[,2]
m5_se_lin_clust<-m5_for_ci_lin_clust[2]
m5_est_lin_clust<-m5_for_ci_lin_clust[1]
m5_ci_lin_clust<- m5_se_lin_clust*ci
high_m5_lin_clust <- m5_est_lin_clust + m5_ci_lin_clust
low_m5_lin_clust <- m5_est_lin_clust - m5_ci_lin_clust

# m6 ###################
m6_for_ci_lin_clust <-att_d_lin_clust$att.model[,2]
m6_se_lin_clust<-m6_for_ci_lin_clust[2]
m6_est_lin_clust<-m6_for_ci_lin_clust[1]
m6_ci_lin_clust<- m6_se_lin_clust*ci
high_m6_lin_clust <- m6_est_lin_clust + m6_ci_lin_clust
low_m6_lin_clust<- m6_est_lin_clust - m6_ci_lin_clust

# m7 ###################
m7_for_ci_lin_clust <-att_w_lin_clust$att.model[,2]
m7_se_lin_clust<-m7_for_ci_lin_clust[2]
m7_est_lin_clust<-m7_for_ci_lin_clust[1]
m7_ci_lin_clust<- m7_se_lin_clust*ci
high_m7_lin_clust <- m7_est_lin_clust + m7_ci_lin_clust
low_m7_lin_clust <- m7_est_lin_clust - m7_ci_lin_clust

# m8 ###################
m8_for_ci_lin_clust <-att_vw_lin_clust$att.model[,2]
m8_se_lin_clust<-m8_for_ci_lin_clust[2]
m8_est_lin_clust<-m8_for_ci_lin_clust[1]
m8_ci_lin_clust<- m8_se_lin_clust*ci
high_m8_lin_clust <- m8_est_lin_clust + m8_ci_lin_clust
low_m8_lin_clust <- m8_est_lin_clust- m8_ci_lin_clust

#m9 ######################
m9_for_ci_lin_clust <-att_vhvd_lin_clust$att.model[,2]
m9_se_lin_clust<-m9_for_ci_lin_clust[2]
m9_est_lin_clust<-m9_for_ci_lin_clust[1]
m9_ci_lin_clust<- m9_se_lin_clust*ci
high_m9_lin_clust <- m9_est_lin_clust + m9_ci_lin_clust
low_m9_lin_clust<- m9_est_lin_clust - m9_ci_lin_clust

#m10 ######################
m10_for_ci_lin_clust <-att_hd_lin_clust$att.model[,2]
m10_se_lin_clust<-m10_for_ci_lin_clust[2]
m10_est_lin_clust<-m10_for_ci_lin_clust[1]
m10_ci_lin_clust<- m10_se_lin_clust*ci
high_m10_lin_clust <- m10_est_lin_clust + m10_ci_lin_clust
low_m10_lin_clust <- m10_est_lin_clust - m10_ci_lin_clust


save(att_vh_lin_clust, file = "att_vh_lin_clust_VAC.RData")
save(att_h_lin_clust, file = "att_h_lin_clust_VAC.RData")
save(att_c_lin_clust, file = "att_c_lin_clust_VAC.RData")
save(att_vc_lin_clust, file = "att_vc_lin_clust_VAC.RData")
save(att_vw_lin_clust, file = "att_vw_lin_clust_VAC.RData")
save(att_w_lin_clust, file = "att_w_lin_clust_VAC.RData")
save(att_d_lin_clust, file = "att_d_lin_clust_VAC.RData")
save(att_vd_lin_clust, file = "att_vd_lin_clust_VAC.RData")
save(att_vhvd_lin_clust, file = "att_vhvd_lin_clust_VAC.RData")
save(att_hd_lin_clust, file = "att_hd_lin_clust_VAC.RData")


##### plot figure
pdf("lin_clust_196_VAC_onlygrid.pdf",10,6)
par(mar=c(6, 11, 6, 15))

plot(m1_est_lin_clust,10, pch=18, cex = .25, xlim = c(-.03,.01), ylim = c(0,10), 
yaxt = 'n', xlab="Treatment effect on the treated \n (Events per grid/month)", ylab = '  ',
main = "Weather indicator effects upon conflict \n (Grid clustered SEs; 'VAC' only)"
)

abline(v = 0, col = "gray50", lty=2)
axis(2, at = c(10:1), labels = labels, las=2, cex.axis = 1, font = 2)

#m1
arrows (low_m1_lin_clust,10,high_m1_lin_clust,10,length = 0,lwd=3, col = "firebrick3")
points(m1_est_lin_clust,10,pch = 16,cex=1,col = "firebrick3")
text(m1_est_lin_clust,9.75, round(m1_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m2
arrows (low_m2_lin_clust,9,high_m2_lin_clust,9,length = 0,lwd=3, col = "firebrick3")
points(m2_est_lin_clust,9,pch = 16,cex=1,col = "firebrick3")
text(m2_est_lin_clust,8.75, round(m2_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m3
arrows (low_m3_lin_clust,8,high_m3_lin_clust,8,length = 0,lwd=3, col = "firebrick3")
points(m3_est_lin_clust,8,pch = 16,cex=1,col = "firebrick3")
text(m3_est_lin_clust,7.75, round(m3_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m4
arrows (low_m4_lin_clust,7,high_m4_lin_clust,7,length = 0,lwd=3, col = "firebrick3")
points(m4_est_lin_clust,7,pch = 16,cex=1,col = "firebrick3")
text(m4_est_lin_clust,6.75, round(m4_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m5
arrows (low_m5_lin_clust,6,high_m5_lin_clust,6,length = 0,lwd=3, col = "firebrick3")
points(m5_est_lin_clust,6,pch = 16,cex=1,col = "firebrick3")
text(m5_est_lin_clust,5.75, round(m5_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m6
arrows (low_m6_lin_clust,5,high_m6_lin_clust,5,length = 0,lwd=3, col = "firebrick3")
points(m6_est_lin_clust,5,pch = 16,cex=1,col = "firebrick3")
text(m6_est_lin_clust,4.75, round(m6_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m7 
arrows (low_m7_lin_clust,4,high_m7_lin_clust,4,length = 0,lwd=3, col = "firebrick3")
points(m7_est_lin_clust,4,pch = 16,cex=1,col = "firebrick3")
text(m7_est_lin_clust,3.75, round(m7_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m8
arrows (low_m8_lin_clust,3,high_m8_lin_clust,3,length = 0,lwd=3, col = "firebrick3")
points(m8_est_lin_clust,3,pch = 16,cex=1,col = "firebrick3")
text(m8_est_lin_clust,2.75, round(m8_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m9
arrows (low_m9_lin_clust,2,high_m9_lin_clust,2,length = 0,lwd=3, col = "firebrick3")
points(m9_est_lin_clust,2,pch = 16,cex=1,col = "firebrick3")
text(m9_est_lin_clust,1.75, round(m9_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)

#m10
arrows (low_m10_lin_clust,1,high_m10_lin_clust,1,length = 0,lwd=3, col = "firebrick3")
points(m10_est_lin_clust,1,pch = 16,cex=1,col = "firebrick3")
text(m10_est_lin_clust,.75, round(m10_est_lin_clust,digits=4), col = "black", cex = 1, font = 2)



L1<-as.numeric(imb_tab_final$L1)
L1<-round (L1, digits= 5)
L1 <- paste("; L1 = ", L1, "; ")
LCS <- as.numeric (imb_tab_final$LCS)
LCS <- round (LCS, digits=5)
LCS <- paste("LCS = ", LCS, ")")

all_balance <- paste (L1,LCS, sep = "")

matched_n<-paste("(N = ", matched_ns, all_balance, sep = "")

### HERE concatonate a "match L1 = " into the character string

axis(4, at = c(10:1), labels = matched_n, font =3, las=2, xaxt = 'n',tick = FALSE, cex.axis = .75)

dev.off()

