###############################################
# 7 Apr 2014
#	parallel bootstrap procedure using multilevel sampling approach
#
###############################################

#pckg <- "parallel"
#if (!is.element(pckg, installed.packages()[,1])) {
#	install.packages(pkgs=pckg, repos="http://cran.case.edu/", dependencies=TRUE)
#}
library(parallel)	# is a standard package

# INSTRUCTIONS: set model name here
## Table 1
#modelName <- "NullPoisson"				# Table S1, model i
#modelName <- "MainPoisson"				# Table S1, model ii
## Table S4
#modelName <- "MainLinear"				# Table S4
## Table S5
#modelName <- "RiotsPoisson"			# Table S5, model i
#modelName <- "CivsPoisson"				# Table S5, model ii
#modelName <- "BattlesPoisson"			# Table S5, model iii
#modelName <- "UCDP_poisson"			# Table S5, model iv
#modelName <- "MainPoissonUCDPsubset"	# Table S5, model v
## Table S6
#modelName <- "EasternPoisson"			# Table S6, model i
#modelName <- "CentralPoisson"			# Table S6, model ii
#modelName <- "SahelPoisson"			# Table S6, model iii
#modelName <- "SouthernPoisson"			# Table S6, model iv
#modelName <- "WesternPoisson"			# Table S6, model v
#modelName <- "GrasslandPoisson"		# Table S6, model vi
## Table S7
#modelName <- "FH_PolRghtsSqrd2_simple"	# Table S7, model ii
#modelName <- "PolityPoisson"			# Table S7, model iii
#modelName <- "PolitySqrd2_simple"		# Table S7, model iv


# INSTRUCTIONS: set directories here
baseDir <- "C://Users/XXX/"
baseDir <- "F://Private/witmer/SubSahAfrica/Analysis/PNAS_SSA_RepTest/"
inDir <- baseDir
outDir <- paste(baseDir, modelName, "/", sep="") # must create this directory
if (!file.exists(substr(outDir, 1, nchar(outDir)-1)))
	print(paste("ERROR: invalid outDir", outDir))

## extract next thread number from saved LastThreadNum.csv
threadNumFile <- paste(inDir, "LastThreadNum.csv", sep="")
lastThreadNum <- read.csv(file=threadNumFile)
threadNum <- lastThreadNum[1,1] + 1
#threadNum <- 8
write.csv(threadNum, file=threadNumFile, row.names=FALSE)
print(paste("Thread number incremented to", threadNum, "and written to file"))


# load model analysis functions
source(paste(inDir, "SharedClimateModelFunctions.R", sep=""))
source(paste(inDir, "SharedMultilevelFunctions.R", sep=""))

## load data
load(file=paste(inDir, "pastLongDataB_W.Rdata", sep=""))

## rescale variables with large variances (e.g. > 10)
#  http://www.statmodel.com/discussion/messages/11/10107.html?1342535702
#sort(sapply(c(depVar, tradVars, meanDemeanVars), function(x) var(pastLongData[, x])))	# IMR 32.5 & 52.8
for (var in c("IMR_lag12_demean", "IMR_lag12_mean")) { 
    pastLongData[[paste(var, "_RS", sep="")]] <- myRescale(pastLongData[[var]], sdMult=1)
}

## setup common variables; overwrite as necessary below
timeVariantVars <- c("SPI6_CRU", "TI6_CRU", "GPWpopLn", "IMR_lag12", "PR_lag12")
meanDemeanVars <- appendMeanDemean(timeVariantVars)
meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])
tradVars <- c("EthLeader", "ElectPres", "CptlDV", "BrdrDistLnKm", "DistToRdLn", "FactivaLn")
## set default model options; overwrite as necessary below
funcForm <- "poisson"
depVar <- "Events"
UCDP_subset <- FALSE
regName <- ""
numBoot <- 100	# number of bootstrap models

if (modelName == "MainPoisson") {
	# this is the main model, no need to change any default parameters
}
if (modelName == "MainLinear") {
	funcForm <- "linear"
}
if (modelName == "RiotsPoisson") {
	depVar <- "EventRiots";
}
if (modelName == "CivsPoisson") {
	depVar <- "EventCivs";
}
if (modelName == "BattlesPoisson") {
	depVar <- "EventBattles";
}
if (modelName == "UCDP_poisson") {
	depVar <- "UCDP_Events"
	UCDP_subset <- TRUE
}
if (modelName == "MainPoissonUCDPsubset") {
	UCDP_subset <- TRUE
}
if (modelName == "EasternPoisson") {
	regName <- "Eastern"
	regVar <- "Region"
	numBoot <- 150	# run extra simulation models to cover those that fail
}
if (modelName == "CentralPoisson") {
	regName <- "Central"
	regVar <- "Region2"
	numBoot <- 120	# run extra simulation models to cover those that fail
}
if (modelName == "SahelPoisson") {
	regName <- "Sahel"
	regVar <- "Region2"
	numBoot <- 120	# run extra simulation models to cover those that fail
}
if (modelName == "SouthernPoisson") {
	regName <- "Southern"
	regVar <- "Region2"
	numBoot <- 130	# run extra simulation models to cover those that fail
}
if (modelName == "WesternPoisson") {
	regName <- "Western"
	regVar <- "Region2"
	numBoot <- 110	# run extra simulation models to cover those that fail
}
if (modelName == "GrasslandPoisson") {
	regName <- "Grassland"
}
if (modelName == "FH_PolRghtsSqrd2_simple") {
	# square PR term 
	pastLongData$PR_lag12_mean_sqrd <- pastLongData$PR_lag12_mean^2
	pastLongData$PR_lag12_demean_sqrd <- pastLongData$PR_lag12_demean^2

	meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10], "PR_lag12_mean_sqrd", "PR_lag12_demean_sqrd")
}
if (modelName == "PolityPoisson") {
	timeVariantVars <- c("SPI6_CRU", "TI6_CRU", "GPWpopLn", "IMR_lag12", "polity2_lag12")
	meanDemeanVars <- appendMeanDemean(timeVariantVars)
	meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])
}
if (modelName == "PolitySqrd2_simple") {
	timeVariantVars <- c("SPI6_CRU", "TI6_CRU", "GPWpopLn", "IMR_lag12", "polity2_lag12")
	meanDemeanVars <- appendMeanDemean(timeVariantVars)
	# square polity2 term 
	pastLongData$polity2_lag12_mean_sqrd <- pastLongData$polity2_lag12_mean^2
	pastLongData$polity2_lag12_demean_sqrd <- pastLongData$polity2_lag12_demean^2
	
	meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10], "polity2_lag12_mean_sqrd", "polity2_lag12_demean_sqrd")
}

### subset UCDP-GED v1.5 to Feb 1989 - Dec 2010
if (UCDP_subset == TRUE) {
	#head(pastLongData$rowID); tail(pastLongData$rowID) # Feb 1980 - Dec 2012
	#table(pastLongData$Year)
	ucdpLongData <- pastLongData[pastLongData$Year %in% (1989:2010 - 1980 + 1), ]
	#nrow(ucdpLongData)
	#head(ucdpLongData$rowID); tail(ucdpLongData$rowID) # Jan 1989 - Dec 2010
	#ucdpLongData <- ucdpLongData[-c(1:numGrids), ] # remove Jan 1989
	ucdpLongData <- ucdpLongData[!(ucdpLongData$Year == (1989-1980+1) & ucdpLongData$Month == 1), ] # remove Jan 1989
	#nrow(ucdpLongData)
	#head(ucdpLongData$rowID); tail(ucdpLongData$rowID) # Feb 1989 - Dec 2010
	#table(ucdpLongData$Year)
	pastData <- ucdpLongData; samplePctSize <- "UCDP"
} else if (regName != "") {
	#for (regName in levels(pastLongData$Region)) {	# regName <- "Central"
	if (regName == "Grassland")
		pastData <- pastLongData[pastLongData$PctGrassland >= 50, ]
	else
		pastData <- pastLongData[pastLongData[[regVar]] == regName, ]
	samplePctSize <- regName
	print(paste(regName, "num rows:", nrow(pastData)))
} else {
	pastData <- pastLongData; samplePctSize <- 100
}
## subset data for testing
if (FALSE) {
  numBoot <- 6
  samplePctSize <- 5
  subsetI <- sort(sample(1:nrow(pastLongData), size=nrow(pastLongData)*samplePctSize/100))
  pastData <- pastLongData[subsetI, ]
}

print(paste("number of observations =", nrow(pastData)))


if (modelName == "NullPoisson") {
	allPredVars <- NULL
	mlmText <- paste(depVar, " ~ ", sep="")
	groupColName <- "Country"
	mlmFormula <- as.formula(paste(mlmText,"(1 | ",groupColName,")", sep=""))
	print(mlmFormula)
} else {
  allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanRsVars, tradVars)
  mlmText <- paste(depVar, " ~ ", paste(allPredVars, "+ ", collapse=""), sep="")
  groupColName <- "Country"
  mlmFormula <- as.formula(paste(mlmText,"(1 | ",groupColName,")", sep=""))
  print(mlmFormula)
}

bootSims <- NULL
datLevels <- c("Country", "Grid", "Month")
# MUST reduce dataframe size, else resampleMLM() consumes all RAM!
pastData$Id <- 1:nrow(pastData)
pastDataSmall <- pastData[, c("Id", datLevels)]
# remove excess columns since entire data frame
pastData <- pastData[, c(depVar, allPredVars, datLevels)]
#pastData <- pastData[, c(depVar, allPredVars, groupColName, datLevels)]
gc()

## multithreaded implementation
#	use outfile option in makeCluster() to capture print statements & warnings
#	drawback is if one thread takes much longer to finish, saving to the complete results is delayed & RAM not released
numClust <- 6	# specify number of processors to use
print(paste("starting",funcForm,"for thread number", threadNum, "and", numBoot, "bootstrap simulations using", numClust, "processors")); flush.console()
startTime <- proc.time()
if (numClust >= 2) {
	cl <- makeCluster(numClust, outfile=paste(outDir, "outfile_",threadNum,".txt", sep=""))
	# export data & functions [TODO: clean this up so less data has to be distributed to each node?]
	clusterExport(cl, c("pastData", "pastDataSmall", "datLevels", "mlmFormula", "funcForm", "threadNum", "outDir")) 
	clusterExport(cl, c("bootLoop", "sampleLMER", "resampleMLM", "writeLMER", "residPlotLMER", "calcAUC", "elapsedTime"))
	clusterEvalQ(cl, require(lme4)); clusterEvalQ(cl, require(Hmisc))
	clusterEvalQ(cl, options("warn" = 1)) # print warnings as they occur (will then be captured in outfile_*.txt)
	set.seed(threadNum)	 # set seed so that results are replicable
	bootSims <- parLapplyLB(cl, 1:numBoot, function(x) bootLoop(x))
	# shut down the cluster
	stopCluster(cl)
} else {
	set.seed(threadNum)	 # set seed so that results are replicable
	# TODO: log output to a file & use options("warn" = 1)
	bootSims <- lapply(1:numBoot, function(x) bootLoop(x))
}
## insert NAs for missing coeffs
print("number of coeffs in each model:"); print(sapply(1:length(bootSims), function(x) length(bootSims[[x]])))
bootSimsNAs <- lapply(1:length(bootSims), function(x) {
	coefVec <- rep(NA, length(allPredVars)+1)
	names(coefVec) <- c("(Intercept)", allPredVars)
	coefVec[names(bootSims[[x]])] <- bootSims[[x]]
	coefVec
	})
#sapply(1:length(bootSimsNAs), function(x) length(bootSimsNAs[[x]]))
bootSimsDF <- do.call(cbind, bootSimsNAs)
save(bootSimsDF, file=paste(outDir, "bootSimsDF_",regName,"_",threadNum,"_",numBoot,".Rdata", sep=""))
print(paste("finished", samplePctSize, "%,", funcForm,"for thread number", threadNum, "and", numBoot, "bootstrap simulations in", elapsedTime(startTime)))

gc()

# also run full model once with original data
if (TRUE) {
	lmerObj <- fullLMER(pastData, mlmFormula, funcForm)
	save(lmerObj, file=paste(outDir, modelName, ".Rdata", sep=""))
	## calculate bootstrapped SE and z-stats for the estimate coefficients
	#  bootCombDF <- bootSimsDF
	bootCombDF <- bootSimsDF[, 1:100] # for consistency, use first 100 simulations
	numCoeffs <- length(allPredVars)
	summComb <- data.frame(fullCoef=coef(summary(lmerObj))[1:(numCoeffs+1), "Estimate"],
	                       bootMeanCoef=apply(bootCombDF, 1, mean),
	                       bootSE=apply(bootCombDF, 1, sd))
	summComb$Zstat <- summComb$fullCoef / summComb$bootSE
	summComb
	write.csv(summComb, file=paste(outDir, modelName, "bootSE_",ncol(bootCombDF),".csv", sep=""))
	gc()
}


