###############################################
# 14 Apr 2014
#	generate pred. power plot for linear models generated from lmer
#
###############################################

baseDir <- "C://Users/XXX/"
inDir <- baseDir
outDir <- paste(baseDir, "PredPowerLinearBoot/", sep="") # must create this directory
if (!file.exists(substr(outDir, 1, nchar(outDir)-1)))
	print(paste("ERROR: invalid outDir", outDir))

# load model analysis functions
source(paste(inDir, "SharedClimateModelFunctions.R", sep=""))
source(paste(inDir, "SharedMultilevelFunctions.R", sep=""))

load(file=paste(inDir, "pastLongDataB_W.Rdata", sep=""))

# setup common vars & formula
timeVariantVars <- c("SPI6_CRU", "TI6_CRU", "GPWpopLn", "IMR_lag12", "PR_lag12")
meanDemeanVars <- appendMeanDemean(timeVariantVars)
tradVars <- c("EthLeader", "ElectPres", "CptlDV", "BrdrDistLnKm", "DistToRdLn", "FactivaLn")
depVar <- "Events";
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanVars, tradVars)

## rescale variables with large variances (e.g. > 10)
sort(sapply(allPredVars, function(x) var(pastLongData[, x])))	# IMR 32.5 & 52.8
for (var in c("IMR_lag12_demean", "IMR_lag12_mean")) { 
	pastLongData[[paste(var, "_RS", sep="")]] <- myRescale(pastLongData[[var]], sdMult=1)
}
colnames(pastLongData)
meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])


## run pred. power plots for linear model
pastData <- pastLongData; samplePctSize <- 100
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanRsVars, tradVars)
funcForm <- "linear"
modelName <- paste("lmer_", samplePctSize, "pct", sep="")
# 14 apr 2014, run w/ lme4_1.1-5, R 3.0.3 & rescaled IMR variables
AUCs <- calcMLM_PredPower(depVar, allPredVars, pastData, funcForm, 1:length(allPredVars)) # 7.7 mins 

### can restart here ###
# loop through all 'no' .csv files & extract AUCs
meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanRsVars, tradVars)
AUCs <- vector("numeric", length(allPredVars))
names(AUCs) <- allPredVars
baseModelName <- "lmer"
for (noVar in allPredVars) { # noVar <- allPredVars[1]
	noModel <- read.csv(file=paste(outDir, baseModelName, "_no",noVar,".csv", sep=""), as.is=TRUE)
	AUCs[noVar] <- as.numeric(noModel[noModel[,1]=="AUC", "Estimate"])
}
baseModel <- read.csv(file=paste(inDir, "MainLinear/", "lmer_full_11Apr14_11_54_44",".csv", sep=""), as.is=TRUE)
base_AUC <- as.numeric(baseModel[baseModel[,1]=="AUC", "Estimate"])

predPower <- base_AUC - AUCs	# calculate predictive power for all
#write.csv(rev(sort(predPower)), paste(outDir, baseModelName, "predPowerSort.csv", sep=""))

# get Z values from bootstrap results
bootSampleSE <- read.csv(file=paste(inDir, "MainLinear/", "bootSampleSE_100.csv", sep=""), as.is=TRUE)

# remove intercept, retain z-scores
baseZs <- abs(bootSampleSE[-1, c("Zstat")])

# W = within = demean
# B = between = mean
displayNames <- c("Events space-time lag", "SPI6 B", "SPI6 W", "TI6 B", "TI6 W", 
 "Population B", "Population W", "IMR B", "IMR W", "Pol'l rights B", 
 "Pol'l rights W", "Ethnic", "Pres. elect.", "Capital city", "Dist. to border", 
 "Dist. to road", "Factiva")
modelName <- paste("lmer", sep="")
filePrefix <- paste(modelName, "_PredPower", sep="")
pdf(file=paste(outDir, filePrefix, ".pdf", sep=""), width=7, height=5)
	#par(mar=c(5,6,4,2),mgp=c(3,1,0),las=1)	# Hmmmm, margin fiddling?
	# range(baseZs); range(predPower)
	minY <- -0.008;	maxY <- 0.04
	minX <- 0; maxX <- 5
	fsize <- 1.1
	plot(baseZs, predPower, type="n",bty="n",xlim=c(minX,maxX),ylim=c(minY,maxY),ylab="Change in predictive power (AUC)",xlab="Statistical significance (absolute z value)", main="Predictive power for variables in linear MLM-RE model", cex.lab=fsize, cex.axis=fsize)
	segments(x0=0,x1=max(baseZs),y0=0,y1=0,col="red", lwd=1)	# red line at y=0
	# add a line showing the regression line estimated intercept=0:
	model1 <- lm(predPower~0+baseZs)
	segments(x0=min(baseZs),y0=min(baseZs)*model1$coefficients,x1=max(baseZs),y1=max(baseZs)*model1$coefficients, lwd=1, col="grey")
	# add the points and spline lines
	points(baseZs, predPower, pch=19, cex=0.7)
	# add a text labels to points w/ low predPower
	xIs <- yIs <- which(predPower < 0.0005)
	h.adj <- rep(-0.05, length(xIs)); v.adj <- rep(-0.0007, length(xIs))
	h.adj[names(xIs) == "TI6_CRU_demean"] <- -.1
	h.adj[names(xIs) == "GPWpopLn_mean"] <- .1
	v.adj[names(xIs) == "ElectPres"] <- .007
	h.adj[names(xIs) == "ElectPres"] <- .2
	text(baseZs[xIs]+h.adj,predPower[yIs]+v.adj,displayNames[yIs],adj=1,srt=60,cex=0.6)
	# add a text labels to points w/ high predPower
	xIs <- yIs <- which(predPower >= 0.0005)
	h.adj <- rep(0.05, length(xIs)); v.adj <- rep(0.001, length(xIs))
	#h.adj[names(xIs) == "GPWpopLn_demean"] <- -.6
	v.adj[names(xIs) == "CptlDV"] <- -0.0005
	text(baseZs[xIs]+h.adj,predPower[yIs]+v.adj,displayNames[yIs],adj=0,srt=0,cex=0.6)
dev.off()
