###############################################
# 1 Apr 2014
#	generate pred. power plot for poisson models generated from glmer
#
###############################################

baseDir <- "C://Users/XXX/"
inDir <- baseDir
outDir <- paste(baseDir, "PredPowerPoisBoot/", sep="") # must create this directory
if (!file.exists(substr(outDir, 1, nchar(outDir)-1)))
	print(paste("ERROR: invalid outDir", outDir))

# load model analysis functions
source(paste(inDir, "SharedClimateModelFunctions.R", sep=""))
source(paste(inDir, "SharedMultilevelFunctions.R", sep=""))

load(file=paste(inDir, "pastLongDataB_W.Rdata", sep=""))

# setup common vars & formula
timeVariantVars <- c("SPI6_CRU", "TI6_CRU", "GPWpopLn", "IMR_lag12", "PR_lag12")
meanDemeanVars <- appendMeanDemean(timeVariantVars)
tradVars <- c("EthLeader", "ElectPres", "CptlDV", "BrdrDistLnKm", "DistToRdLn", "FactivaLn")
depVar <- "Events";
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanVars, tradVars)

## rescale variables with large variances (e.g. > 10)
sort(sapply(allPredVars, function(x) var(pastLongData[, x])))	# IMR 32.5 & 52.8
for (var in c("IMR_lag12_demean", "IMR_lag12_mean")) { 
	pastLongData[[paste(var, "_RS", sep="")]] <- myRescale(pastLongData[[var]], sdMult=1)
}
colnames(pastLongData)
meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])


## run pred. power plots for poisson model
pastData <- pastLongData; samplePctSize <- 100
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanRsVars, tradVars)
modelName <- paste("glmer_pois_", samplePctSize, "pct", sep="")
# 1 apr 2014, re-run w/ lme4_1.1-5 & rescaled IMR variables
AUCs <- calcMLM_PredPower(depVar, allPredVars, pastData, "poisson", 1:4) # 10 hrs
AUCs <- calcMLM_PredPower(depVar, allPredVars, pastData, "poisson", 5:8) # 9 hrs
AUCs <- calcMLM_PredPower(depVar, allPredVars, pastData, "poisson", 9:12) # 10 hrs
AUCs <- calcMLM_PredPower(depVar, allPredVars, pastData, "poisson", 13:17) # 13 hrs

### can restart here ###
# loop through all 'no' .csv files & extract AUCs
meanDemeanRsVars <- c(meanDemeanVars[1:6], "IMR_lag12_mean_RS", "IMR_lag12_demean_RS", meanDemeanVars[9:10])
allPredVars <- c(paste(depVar, "SpLag_lag1", sep=""), meanDemeanRsVars, tradVars)
AUCs <- vector("numeric", length(allPredVars))
names(AUCs) <- allPredVars
baseModelName <- "glmer_pois"
for (noVar in allPredVars) { # noVar <- allPredVars[1]
	noModel <- read.csv(file=paste(outDir, baseModelName, "_no",noVar,".csv", sep=""), as.is=TRUE)
	AUCs[noVar] <- as.numeric(noModel[noModel[,1]=="AUC", "Estimate"])
}
baseModel <- read.csv(file=paste(outDir, "../", baseModelName, "_RS_100pct",".csv", sep=""), as.is=TRUE)
base_AUC <- as.numeric(baseModel[baseModel[,1]=="AUC", "Estimate"])
#base_AUC <- 0.8516214 # grab from glmer_pois_RS_100pct.csv 

predPower <- base_AUC - AUCs	# calculate predictive power for all
#write.csv(rev(sort(predPower)), paste(outDir, baseModelName, "predPowerSort.csv", sep=""))

# get Z values from bootstrap results
bootSampleSE <- read.csv(file=paste(inDir, "MainPoisson/", "bootSampleSE_100.csv", sep=""), as.is=TRUE)

# remove intercept, retain z-scores
baseZs <- abs(bootSampleSE[-1, c("Zstat")])

# W = within = demean
# B = between = mean
displayNames <- c("Events space-time lag", "SPI6 B", "SPI6 W", "TI6 B", "TI6 W", 
 "Population B", "Population W", "IMR B", "IMR W", "Pol'l rights B", 
 "Pol'l rights W", "Ethnic", "Pres. elect.", "Capital city", "Dist. to border", 
 "Dist. to road", "Factiva")
modelName <- paste("glmer_pois", sep="")
filePrefix <- paste(modelName, "_PredPower", sep="")
pdf(file=paste(outDir, filePrefix, ".pdf", sep=""), width=7, height=5)
	#par(mar=c(5,6,4,2),mgp=c(3,1,0),las=1)	# Hmmmm, margin fiddling?
	# range(baseZs); range(predPower)
	minY <- -0.005;	maxY <- 0.03
	minX <- 0; maxX <- 6
	fsize <- 1.1
	plot(baseZs, predPower, type="n",bty="n",xlim=c(minX,maxX),ylim=c(minY,maxY),ylab="Change in predictive power (AUC)",xlab="Statistical significance (absolute z value)", main="Predictive power for variables in poisson MLM-RE model", cex.lab=fsize, cex.axis=fsize)
	segments(x0=0,x1=max(baseZs),y0=0,y1=0,col="red", lwd=1)	# red line at y=0
	# add a line showing the regression line estimated intercept=0:
	model1 <- lm(predPower~0+baseZs)
	segments(x0=min(baseZs),y0=min(baseZs)*model1$coefficients,x1=max(baseZs),y1=max(baseZs)*model1$coefficients, lwd=1, col="grey")
	# add the points and spline lines
	points(baseZs, predPower, pch=19, cex=0.7)
	# add a few text labels
	h.adj <- -0.05; v.adj <- -0.0007
	xIs <- yIs <- which(predPower < 0.0005)
	text(baseZs[xIs]+h.adj,predPower[yIs]+v.adj,displayNames[yIs],adj=1,srt=60,cex=0.6)
	xIs <- yIs <- which(predPower >= 0.0005)
	h.adj <- rep(0.05, length(xIs)); v.adj <- rep(0.001, length(xIs))
	h.adj[names(xIs) == "GPWpopLn_demean"] <- -.6
	v.adj[names(xIs) == "DistToRdLn"] <- 0.0005
	text(baseZs[xIs]+h.adj,predPower[yIs]+v.adj,displayNames[yIs],adj=0,srt=0,cex=0.6)
dev.off()

